

set -ex



pushd tests
pushd hello_world_py chmod +x ./test.sh
./test.sh
popd
popd
test -f $PREFIX/include/boost/python.hpp
test -d $PREFIX/include/boost/python
test -f $PREFIX/share/boost-build/src/kernel/site-config.jam
test -f $PREFIX/lib/libboost_python.a
test -f $PREFIX/lib/libboost_python38.a
test -f $PREFIX/lib/libboost_python${SHLIB_EXT}
test -f $PREFIX/lib/libboost_python38${SHLIB_EXT}
test -f $PREFIX/lib/libboost_numpy.a
test -f $PREFIX/lib/libboost_numpy38.a
test -f $PREFIX/lib/libboost_numpy${SHLIB_EXT}
test -f $PREFIX/lib/libboost_numpy38${SHLIB_EXT}
exit 0
